@@ -10,7 +10,7 @@ __author__ = "Gokul Kannan G"
 __email__ = "gokulkannan.dev@gmail.com"
 
 # Import main components for easier access
-from .main import main
+from .main import *
 from .cli import main as cli_main
 
 __all__ = ["main", "cli_main", "__version__"]
