@@ -1789,7 +1789,7 @@ def generate_advanced_report(domain_name):
 #
 #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #       #
 #
-if __name__ == "__main__":
+def main():
     # Initialize global results dictionary
     global scan_results
     scan_results = {
@@ -1833,8 +1833,9 @@ if __name__ == "__main__":
             print("17. API Security Testing")
             print("18. AI-Powered Vulnerability Detection")
             print("19. Comprehensive Security Scan")
-            print("20. Advanced Report Generation")
-            print("21. Exit\n")
+            print("20. Running Security Tool Integration")
+            print("21. Advanced Report Generation")
+            print("22. Exit\n")
 
             choice = input("Enter a choice from the given options (1-21): ")
 
@@ -2156,7 +2157,20 @@ if __name__ == "__main__":
                     print("\n[-] No scan results available. Run scans first.")
 
             elif choice == '22':
+                if scan_results['findings']:
+                    print("\n[*] Generating Advanced Security Report...")
+                    reporter = AdvancedSecurityReporter(
+                        domain_name, scan_results)
+                    reports = reporter.generate_all_reports()
+
+                    print("\n[+] Reports generated successfully:")
+                    for format_type, file_path in reports.items():
+                        print(f"  - {format_type.upper()}: {file_path}")
                 print("Thank you for using VulnScan\nExiting...")
                 sys.exit()
             else:
                 print("\nInvalid option. Please enter a valid option (1-21)")
+
+
+if __name__ == "__main__":
+    main()
